#!/bin/sh
#
# (c) 2025, LEAPS - All rights reserved.
#

# Check if the leaps_center Docker container exists
if docker ps -a --format '{{.Names}}' | grep -q '^leaps_center$'; then
  docker rm --force leaps_center
fi

# Check if the leaps_server Docker container exists
if docker ps -a --format '{{.Names}}' | grep -q '^leaps_server$'; then
  docker rm --force leaps_server
fi

# Check if the leaps_gateway Docker container exists
if sudo docker ps -a --format '{{.Names}}' | grep -q '^leaps_gateway$'; then
  sudo docker rm --force leaps_gateway
fi

# Check if the leaps_mosquitto Docker container exists
if docker ps -a --format '{{.Names}}' | grep -q '^leaps_mosquitto$'; then
  docker rm --force leaps_mosquitto
fi

echo "Run leaps_center from hub"
cd leaps_center_hub/
docker run -d -p 80:8080/tcp --name leaps_center -v $PWD/leaps_center/:/app/data/ -e LEAPS_CENTER_HOME=/app/data/ leapslabs/leaps_center:udk1 sh -c "cd /app &&  java -jar leaps-center-web.jar"

echo "Run leaps_server from hub"
cd ../leaps_server_hub/
docker run -d -p 7777:7777/tcp -p 7777:7777/udp --name leaps_server -v "$(pwd)"/data/:/app/data leapslabs/leaps_server:udk1 /app/leaps-server --cfg /app/data/leaps-server.conf

echo "Run leaps_gateway from hub"
cd ../leaps_gateway_hub/
sudo docker run -d -it --name leaps_gateway --privileged -v /dev/bus/usb:/dev/bus/usb -v "$(pwd)"/data/:/app/data leapslabs/leaps_gateway:udk1 /app/leaps-gateway -c /app/data/leaps-gateway.conf

echo "Run leaps_mosquitto from hub"
cd ../
docker run -d -p 1883:1883/tcp -p 15675:15675 --name leaps_mosquitto leapslabs/leaps_mosquitto:udk1 mosquitto -c /mosquitto/config/mosquitto.conf 

echo "Start all containers"
docker start leaps_center
docker start leaps_server
sudo docker start leaps_gateway
docker start leaps_mosquitto
docker ps
